import { IContainer } from 'aurelia';
import { BaseComponent } from '../base-component';
import type { IAwareComponent } from './i-aware-component';
import type { IAwareEvent } from './i-aware-event';
/**
 * Aware Component
 *
 * @category components/events
 *
 * @story Simple
 * ```html
 * <let is-checked.bind="false"></let>
 * <let next-has-been-called.bind="false"></let>
 *
 * <ra-checkbox event-name="my-box" value.bind="isChecked"></ra-checkbox>
 *
 * <aware-component component.ref="awareEvRef"
 *    events.bind="[{ name: 'ra-checkbox:my-box', options: { property: 'value', value: !isChecked } }]"
 *    next.bind="() => nextHasBeenCalled = true"
 * >
 * </aware-component>
 *
 * <button
 *    click.trigger"awareEvRef.publish()"
 * >
 *      Toggled via event
 * </button>
 *
 * <div class="m-5">Result: <strong>${isChecked}</strong> (next called: ${nextHasBeenCalled})</div>
 * ```
 */
export declare class AwareComponent<EBD = unknown> extends BaseComponent<EBD> implements IAwareComponent<EBD> {
    /**
     * Events
     */
    events: Array<{
        name: string;
        options: IAwareEvent;
    }>;
    /** Next */
    next?: (source: AwareComponent) => void | Promise<void>;
    constructor(element: Element, container: IContainer);
    /** Publish the event */
    publish(): Promise<void>;
}
