import { IEventAggregator, IPlatform, type TaskQueue, type IContainer } from 'aurelia';
import { I18N } from '@aurelia/i18n';
import { type IAntiBounce } from '@aegenet/belt-anti-bounce';
import type { IBaseComponent } from './i-base-component';
import { type IAwareComponentService } from './aware/i-aware-component-service';
import type { IHydratedController } from '@aurelia/runtime-html';
import { type IStoreService } from './store/i-store-service';
/**
 * Base component, with basic logic
 */
export declare class BaseComponent<EBD = unknown> implements IBaseComponent {
    protected _element: Element;
    protected _container: IContainer;
    private static _COUNTER;
    /**
     * Instances of anti-bounce
     * @remark Don't edit manually
     *
     * @private
     * @core
     */
    $antiBounces?: Map<string, IAntiBounce>;
    /**
     * AU Slot informations
     * @core
     */
    private readonly _auSlotInfo;
    /**
     * Event aggregator
     * @service
     * @core
     */
    protected readonly _ea: IEventAggregator;
    /**
     * Aware Service
     * @service
     * @core
     */
    protected readonly _aware: IAwareComponentService;
    /**
     * Platform
     * @service
     * @core
     */
    protected readonly _platform: IPlatform;
    /**
     * StoreService
     * @service
     * @core
     */
    protected readonly _store: IStoreService;
    /**
     * i18n
     * @service
     * @core
     */
    readonly i18n: I18N;
    /**
     * Component ID
     * @core
     */
    readonly uid?: string;
    /**
     * Specify a special name for this instance
     *
     * "Je suis spécial !"
     */
    eventName?: string;
    /**
     * Has been init? (attached & _init())
     * @core
     */
    protected _isInit?: boolean;
    /**
     * Have u met T... Slots? (slot)
     * @remark We fill this object with slot only (not au-slot)
     * @core
     */
    slots: Record<string, Element>;
    /**
     * Have u met T... AuSlots? (au-slot)
     * @remark We fill this object with au-slot only (just the name)
     * @core
     */
    auSlots: Record<string, boolean>;
    /**
     * Array of au-slot names
     * @core
     */
    auSlotNames: string[];
    /**
     * Array of slot names
     * @core
     */
    slotNames: string[];
    /**
     * Last error message
     * @core
     */
    lastError?: string;
    /**
     * Is busy ?
     * @core
     */
    isBusy?: boolean;
    /** Embed data */
    embedData?: EBD;
    /**
     * This predicate is called when the value of the bindable (value) property changes.
     *
     * @type callback
     * @input newValue
     * @input oldValue
     * @input embedData
     */
    changed?: (...args: any[]) => void;
    constructor(_element: Element, _container: IContainer);
    /**
     * On attached we refresh slots and au-slots objects, subscribe to aware service,
     * then we call the protected `_init()` method
     */
    attached(): Promise<void>;
    /**
     * Detaching
     */
    detaching(initiator: IHydratedController, parent: IHydratedController): void;
    /**
     * Custom logic (after attached)
     */
    protected _init(): void | Promise<void>;
    /** Custom logic (after detaching and unbinding, before dispose) */
    protected _deinit(): void | Promise<void>;
    /**
     * Refresh slots and au-slots
     */
    private _refreshSlots;
    /**
     * Unbinding
     */
    unbinding(): Promise<void>;
    /**
     * TaskQueue
     * @remark Can be used to rugged SSR
     * @core
     */
    get taskQueue(): TaskQueue;
    /**
     * Event aggregator
     * @service
     * @core
     */
    get ea(): IEventAggregator;
}
