import { type IAntiBounce } from '@aegenet/belt-anti-bounce';
import { I18N } from '@aurelia/i18n';
import { IContainer, IEventAggregator, IPlatform, type TaskQueue } from 'aurelia';
import { IRouter, type RoutingInstruction, type Navigation, type Parameters } from '@aurelia/router';
import type { IBasePage } from './i-base-page';
import { type IAwareComponentService } from './aware/i-aware-component-service';
import { type IStoreService } from './store/i-store-service';
/**
 * Base Page
 */
export declare abstract class BasePage implements IBasePage {
    protected readonly _container: IContainer;
    /**
     * Instances of anti-bounce
     * @remark Don't edit manually
     *
     * @private
     * @core
     */
    $antiBounces?: Map<string, IAntiBounce>;
    /**
     * Event aggregator
     * @service
     * @core
     */
    protected readonly _ea: IEventAggregator;
    /**
     * Specify a special name for this instance
     *
     * "Je suis spécial !"
     */
    eventName?: string;
    /**
     * Aware Service
     * @service
     * @core
     */
    protected readonly _aware: IAwareComponentService;
    /**
     * StoreService
     * @service
     * @core
     */
    protected _store: IStoreService;
    /**
     * i18n
     * @service
     * @core
     */
    readonly i18n: I18N;
    /** Router */
    protected readonly _router: IRouter;
    /**
     * Platform
     * @service
     * @core
     */
    protected readonly _platform: IPlatform;
    /**
     * Has been init? (attached & _init())
     * @core
     */
    protected _isInit?: boolean;
    /**
     * Last error message
     * @core
     */
    lastError?: string;
    constructor(_container: IContainer);
    loading?(parameters: Parameters, instruction: RoutingInstruction, navigation: Navigation): Promise<void>;
    /**
     * Custom logic (on loading)
     */
    protected _init(parameters: Parameters, instruction: RoutingInstruction, navigation: Navigation): void | Promise<void>;
    /** Custom logic (on unloading) */
    protected _deinit(instruction: RoutingInstruction, navigation: Navigation | null): void | Promise<void>;
    /** Unload the page */
    unloading(instruction: RoutingInstruction, navigation: Navigation | null): Promise<void>;
    /**
     * TaskQueue
     * @remark Can be used to rugged SSR
     * @core
     */
    get taskQueue(): TaskQueue;
    /**
     * Event aggregator
     * @service
     * @core
     */
    get ea(): IEventAggregator;
    /** Router */
    get router(): IRouter;
}
